Package: coalitions
Type: Package
Title: Bayesian "Now-Cast" Estimation of Event Probabilities in
        Multi-Party Democracies
Version: 0.6.24
Date: 2022-08-16
Authors@R: c(
    person("Andreas", "Bender", , "bender.at.R@gmail.com", role = c("aut", "cre"), comment=c(ORCID = "0000-0001-5628-8611")),
    person("Alexander", "Bauer", , "alexander.bauer@stat.uni-muenchen.de", role=c("aut"), comment=c(ORCID = "0000-0003-3495-5131")),
    person("Rebekka", "Schade", , "rebekka.schade@stablab.stat.uni-muenchen.de", role=c("ctb")))
Maintainer: Andreas Bender <bender.at.R@gmail.com>
Description: An implementation of a Bayesian framework for the opinion poll
    based estimation of event probabilities in multi-party electoral systems
    (Bender and Bauer (2018) <doi:10.21105/joss.00606>).
Depends: R (>= 3.2.1)
Imports: checkmate, gtools, rvest, xml2, jsonlite, RCurl, rlang,
        magrittr, lubridate, stringr, tidyr (>= 1.0.0), purrr (>
        0.2.2), dplyr (> 0.5.0), ggplot2, tibble (>= 3.0.0)
Suggests: testthat, covr,
Encoding: UTF-8
License: MIT + file LICENSE
URL: https://adibender.github.io/coalitions/
BugReports: https://github.com/adibender/coalitions/issues
RoxygenNote: 7.1.2
LazyData: true
NeedsCompilation: no
Packaged: 2022-08-17 12:17:16 UTC; ab
Author: Andreas Bender [aut, cre] (<https://orcid.org/0000-0001-5628-8611>),
  Alexander Bauer [aut] (<https://orcid.org/0000-0003-3495-5131>),
  Rebekka Schade [ctb]
Repository: CRAN
Date/Publication: 2022-08-17 13:40:12 UTC
Built: R 4.4.0; ; 2024-05-08 07:33:43 UTC; unix
