# Generated by roxygen2: do not edit by hand

export("%>%")
export(as_survey)
export(calculate_prob)
export(calculate_probs)
export(collapse_parties)
export(dHondt)
export(draw_from_posterior)
export(get_entryprobability)
export(get_latest)
export(get_meta)
export(get_probabilities)
export(get_seats)
export(get_surveys)
export(get_surveys_brb)
export(get_surveys_by)
export(get_surveys_nds)
export(get_surveys_rp)
export(get_surveys_saxony)
export(get_surveys_thuringen)
export(gg_survey)
export(hare_niemeyer)
export(have_majority)
export(pool_austria)
export(pool_surveys)
export(prettify_de)
export(prettify_en)
export(prettify_strings)
export(redistribute)
export(scrape_austria)
export(scrape_by)
export(scrape_ltw)
export(scrape_rp)
export(scrape_wahlrecht)
export(sls)
import(checkmate)
import(dplyr)
import(ggplot2)
import(magrittr)
import(rvest)
importFrom(RCurl,getURL)
importFrom(checkmate,assert_character)
importFrom(checkmate,assert_data_frame)
importFrom(checkmate,assert_flag)
importFrom(checkmate,assert_number)
importFrom(checkmate,assert_subset)
importFrom(dplyr,bind_cols)
importFrom(dplyr,filter)
importFrom(dplyr,select)
importFrom(gtools,rdirichlet)
importFrom(jsonlite,fromJSON)
importFrom(lubridate,dmy)
importFrom(lubridate,now)
importFrom(magrittr,"%>%")
importFrom(purrr,compose)
importFrom(purrr,flatten)
importFrom(purrr,flatten_dfc)
importFrom(purrr,map)
importFrom(purrr,map2)
importFrom(purrr,map_chr)
importFrom(purrr,map_dbl)
importFrom(purrr,map_dfr)
importFrom(rlang,.data)
importFrom(rlang,UQS)
importFrom(rlang,syms)
importFrom(stats,runif)
importFrom(stringr,regex)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_replace)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(tibble,as_tibble)
importFrom(tidyr,gather)
importFrom(tidyr,nest)
importFrom(tidyr,unnest)
importFrom(utils,combn)
importFrom(xml2,read_html)
